@@ -4,14 +4,13 @@ OC.L10N.register(
     "Rename" : "Rename",
     "Move" : "Move",
     "Delete" : "حذف کریں",
-    "Search" : "Search",
     "Cancel" : "منسوخ کریں",
+    "Shared with you" : "Shared with you",
     "Title" : "عنوان",
     "Link" : "Link",
     "Notes" : "Notes",
     "Owner" : "Owner",
     "Share link" : "اشتراک لنک",
-    "Select" : "Select",
     "Folder" : "Folder",
     "Save" : "حفظ"
 },
